aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/system/xhost.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/system/xhost.go')
-rw-r--r--internal/system/xhost.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/internal/system/xhost.go b/internal/system/xhost.go
index be44ce1a..f4a520ea 100644
--- a/internal/system/xhost.go
+++ b/internal/system/xhost.go
@@ -5,7 +5,8 @@ import (
"hakurei.app/internal/xcb"
)
// ChangeHosts inserts the target user into X11 hosts and deletes it once its [Enablement] is no longer satisfied.
func (sys *I) ChangeHosts(username string) *I {
sys.ops = append(sys.ops, xhostOp(username))
return sys
@@ -14,7 +15,7 @@ func (sys *I) ChangeHosts(username string) *I {
// xhostOp implements [I.ChangeHosts].
type xhostOp string
-func (x xhostOp) Type() hst.Enablement { return hst.EX11 }
+func (x xhostOp) Type() hst.Enablements { return hst.EX11 }
func (x xhostOp) apply(sys *I) error {
sys.msg.Verbosef("inserting entry %s to X11", x)
@@ -5,7 +5,8 @@ import (
"hakurei.app/internal/xcb"
)
-// ChangeHosts inserts the target user into X11 hosts and deletes it once its [Enablement] is no longer satisfied.
+// ChangeHosts inserts the target user into X11 hosts and deletes it once its
+// [hst.Enablements] is no longer satisfied.
func (sys *I) ChangeHosts(username string) *I {
sys.ops = append(sys.ops, xhostOp(username))